use leptos::prelude::*;
use leptos_meta::*;
use leptos_use::{use_timestamp};
use chrono::prelude::{DateTime, Local, Timelike};
use calendrier::{DateTime as FRDateTime, Timestamp as FRTimestamp};

#[component]
pub fn Times() -> impl IntoView {
    let timestamp = use_timestamp();
    let timezone = Local::now().timezone();
    let seconds_since_epoch = Memo::new(move |_| (timestamp.get() / 1000.0) as i64);
    let local_now = Memo::new(move |_| DateTime::from_timestamp(seconds_since_epoch.get(), 0).unwrap().with_timezone(&timezone));
    let local_now_string = move || local_now.get().to_string();

    let fr_date = Memo::new(move |_| FRDateTime::from_timestamp(FRTimestamp::from_unix(local_now.get().timestamp())));
    let fr_time = Memo::new(move |_| {
        let fr_seconds_from_midnight = ((local_now.get().time().num_seconds_from_midnight() as f64) * (1000.0 / 864.0)).floor() as usize;
        let fr_hours = fr_seconds_from_midnight / (100 * 100);
        let fr_seconds_from_hour = fr_seconds_from_midnight - (100 * 100 * fr_hours);
        let fr_minutes = fr_seconds_from_hour / 100;
        let fr_seconds = fr_seconds_from_hour - (100 * fr_minutes);
        let fr_time = format!("{}:{}:{}", fr_hours, fr_minutes, fr_seconds);
        fr_time
    });
    let fr_date_time = move || format!("{}, {}", fr_date.get().to_string_default(), fr_time.get());

    let fi_date_time = move || local_now.get().format_localized("%A %e %B %Y, %T", chrono::Locale::fi_FI).to_string();

    view! {
        <div class="datetime">
            <p class="unix">{seconds_since_epoch}</p>
            <p class="iso">{local_now_string}</p>
            <p class="fr">{fr_date_time}</p>
            <p class="fi">{fi_date_time}</p>
        </div>
    }
}


#[component]
pub fn App() -> impl IntoView {
    // Provides context that manages stylesheets, titles, meta tags, etc.
    provide_meta_context();

    view! {
        // <Html attr:lang="en" attr:dir="ltr" attr:data-theme="light" />
        <Html attr:lang="en" attr:dir="ltr" />

        // sets the document title
        <Title text="homepage.juustodiilerit.fi" />

        // injects metadata in the <head> of the page
        <Meta charset="UTF-8" />
        <Meta name="viewport" content="width=device-width, initial-scale=1.0" />

        <header>
            <h1><span>homepage</span><span>.juustodiilerit</span><span>.fi</span></h1>
        </header>
        <main class="main-width">
            <Times/>
            <ul class="links">
                <li>
                    <a href="https://forgejo.juustodiilerit.fi">git (forgejo)</a>
                </li>
                <li>
                    <a href="https://mail.juustodiilerit.fi">mail</a>
                </li>
                <li>
                    <a href="https://passbolt.juustodiilerit.fi">passbolt</a>
                </li>
            </ul>
        </main>
    }
}
